@@ -19,28 +19,32 @@
  */
 
 #include <config.h>
-
 #include <stdlib.h>
 #include <string.h>
-#include <gconf/gconf-client.h>
 #include <glib/gi18n.h>
 
+#include <libgossip/gossip-conf.h>
 #include <libgossip/gossip-account.h>
 #include <libgossip/gossip-contact.h>
 #include <libgossip/gossip-debug.h>
 #include <libgossip/gossip-vcard.h>
-#include <libgossip/gossip-utils.h>
 #include <libgossip/gossip-chatroom-provider.h>
 #include <libgossip/gossip-ft-provider.h>
 
+#include "gossip-jid.h"
 #include "gossip-jabber-chatrooms.h"
 #include "gossip-jabber-ft.h"
 #include "gossip-jabber-vcard.h"
 #include "gossip-jabber-services.h"
 #include "gossip-jabber-utils.h"
+
+#ifdef USE_TRANSPORTS
 #include "gossip-transport-accounts.h"
+#endif
+
 #include "gossip-jabber.h"
 #include "gossip-jabber-private.h"
+#include "gossip-sha.h"
 
 #define DEBUG_DOMAIN "Jabber"
 
@@ -93,7 +97,9 @@ struct _GossipJabberPriv {
 	GHashTable            *composing_requests;
 
 	/* Transport stuff... is this in the right place? */
+#ifdef USE_TRANSPORTS
 	GossipTransportAccountList *account_list;
+#endif
 	LmMessageHandler      *subscription_handler;
 };
 
@@ -315,7 +321,6 @@ static JabberData *     jabber_data_new                     (GossipJabber
 							     gpointer                 user_data);
 static void             jabber_data_free                    (JabberData              *data);
 
-extern GConfClient *gconf_client;
 
 G_DEFINE_TYPE_WITH_CODE (GossipJabber, gossip_jabber, GOSSIP_TYPE_PROTOCOL,
 			 G_IMPLEMENT_INTERFACE (GOSSIP_TYPE_CHATROOM_PROVIDER,
@@ -412,6 +417,10 @@ jabber_finalize (GObject *object)
 	if (priv->vcard) {
 		g_object_unref (priv->vcard);
 	}
+
+	if (priv->presence) {
+		g_object_unref (priv->presence);
+	}
 	
 	g_hash_table_destroy (priv->contacts);
 
@@ -425,7 +434,6 @@ jabber_finalize (GObject *object)
 
 	if (priv->connection_timeout_id != 0) {
 		g_source_remove (priv->connection_timeout_id);
-		priv->connection_timeout_id = 0;
 	}
 	
 #ifdef USE_TRANSPORTS
@@ -1346,7 +1354,6 @@ jabber_send_message (GossipProtocol *protocol,
 
 	recipient = gossip_message_get_recipient (message);
 
-	/* FIXME: Create a full JID (with resource) and send to that */
 	recipient_id = gossip_contact_get_id (recipient);
 	resource = gossip_message_get_explicit_resource (message);
 
@@ -1506,7 +1513,7 @@ jabber_set_presence (GossipProtocol *protocol,
 
 	contact = gossip_jabber_get_own_contact (jabber);
 	avatar = gossip_contact_get_avatar (contact, &avatar_size);
-	sha1 = gossip_sha1_string (avatar, avatar_size);
+	sha1 = gossip_sha_hash (avatar, avatar_size);
 
 	gossip_debug (DEBUG_DOMAIN, "Setting presence to:'%s', status:'%s', "
 		      "priority:'%s' sha1:'%s' avatar_size:%" G_GSIZE_FORMAT " avatar:%p", 
@@ -1835,7 +1842,7 @@ jabber_contact_is_avatar_latest (GossipJabber  *jabber,
 		}	
 
 		avatar = gossip_contact_get_avatar (contact, &avatar_size);
-		sha1 = gossip_sha1_string (avatar, avatar_size);
+		sha1 = gossip_sha_hash (avatar, avatar_size);
 		
 		same = g_ascii_strcasecmp (sha1, avatar_node->value) == 0;
 		g_free (sha1);
@@ -2162,63 +2169,41 @@ jabber_get_version (GossipProtocol         *protocol,
 						   error);
 }
 
-#define CONF_HTTP_PROXY_PREFIX "/system/http_proxy"
-
 void
 jabber_set_proxy (LmConnection *conn)
 {
-	gboolean     use_http_proxy;
-	GConfClient *gconf_client;
+	gboolean  use_http_proxy;
+	gchar    *host;
+	gint      port;
+	gboolean  use_auth;
+	gchar    *username;
+	gchar    *password;
 
-	gconf_client = gconf_client_get_default ();
-	
-	use_http_proxy = gconf_client_get_bool (gconf_client,
-						CONF_HTTP_PROXY_PREFIX "/use_http_proxy",
-						NULL);
+	gossip_conf_get_http_proxy (gossip_conf_get (),
+				    &use_http_proxy,
+				    &host,
+				    &port,
+				    &use_auth,
+				    &username,
+				    &password);
 	if (use_http_proxy) {
 		LmProxy  *proxy;
-		gchar    *host;
-		gint      port;
-		gboolean  use_auth;
 		
-		host = gconf_client_get_string (gconf_client,
-						CONF_HTTP_PROXY_PREFIX "/host",
-						NULL);
-
-		port = gconf_client_get_int (gconf_client,
-					     CONF_HTTP_PROXY_PREFIX "/port",
-					     NULL);
-
 		proxy = lm_proxy_new_with_server (LM_PROXY_TYPE_HTTP,
 						  host, (guint) port);
-		g_free (host);
-
 		lm_connection_set_proxy (conn, proxy);
 
-		use_auth = gconf_client_get_bool (gconf_client,
-						  CONF_HTTP_PROXY_PREFIX "/use_authentication",
-						  NULL);
 		if (use_auth) {
-			gchar *username;
-			gchar *password;
-
-			username = gconf_client_get_string (gconf_client,
-							    CONF_HTTP_PROXY_PREFIX "/authentication_user",
-							    NULL);
-			password = gconf_client_get_string (gconf_client,
-							    CONF_HTTP_PROXY_PREFIX "/authentication_password",
-							    NULL);
 			lm_proxy_set_username (proxy, username);
 			lm_proxy_set_password (proxy, password);
-
-			g_free (username);
-			g_free (password);
 		}
 		
 		lm_proxy_unref (proxy);
 	}
 
-	g_object_unref (gconf_client);
+	g_free (host);
+	g_free (username);
+	g_free (password);
 }
 
 static gboolean
