@@ -21,9 +21,12 @@
 #include <config.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-druid.h>
 #include <glib/gi18n.h>
 
+#ifdef HAVE_GNOME
+#include <libgnomeui/gnome-druid.h>
+#endif
+
 #include <libgossip/gossip-utils.h>
 
 #include "gossip-account-chooser.h"
@@ -82,6 +85,8 @@ enum {
 	COL_SYS_COUNT
 };
 
+#ifdef HAVE_GNOME
+
 static void           add_contact_window_setup_systems                (GList            *accounts,
 								       GossipAddContact *window);
 static gboolean       add_contact_window_complete_group_idle          (GossipAddContact *window);
@@ -575,7 +580,7 @@ gossip_add_contact_window_show (GtkWindow     *parent,
 	window->group_completion = g_completion_new (NULL);
 
 	glade = gossip_glade_get_file (
-		GLADEDIR "/main.glade",
+		"main.glade",
 		"add_contact_window",
 		NULL,
 		"add_contact_window", &window->window,
@@ -692,3 +697,14 @@ gossip_add_contact_window_show (GtkWindow     *parent,
 
 	gtk_widget_show (window->window);
 }
+
+#else 
+
+void
+gossip_add_contact_window_show (GtkWindow     *parent,
+				GossipContact *contact)
+{
+}
+
+#endif
+
