@@ -21,16 +21,19 @@
  */
 
 #include <config.h>
-#include <sys/utsname.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <stdlib.h>
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <loudmouth/loudmouth.h>
 #include <glib/gi18n.h>
+
+#ifdef HAVE_GNOME
 #include <libgnomeui/libgnomeui.h>
+#include "eggtrayicon.h"
+#endif
 
 #include <libgossip/gossip-contact.h>
 #include <libgossip/gossip-debug.h>
@@ -38,8 +41,7 @@
 #include <libgossip/gossip-presence.h>
 #include <libgossip/gossip-protocol.h>
 #include <libgossip/gossip-utils.h>
-
-#include "eggtrayicon.h"
+#include <libgossip/gossip-conf.h>
 
 #include "gossip-about-dialog.h"
 #include "gossip-account-button.h"
@@ -81,6 +83,7 @@
 #include "gossip-notify.h"
 #endif
 
+
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_APP, GossipAppPriv))
 
 #define DEBUG_DOMAIN_SETUP     "AppSetup"
@@ -91,6 +94,8 @@
 #define DEBUG_DOMAIN_TRAY      "AppTray"
 #define DEBUG_DOMAIN_SESSION   "AppSession"
 
+#define DEBUG_QUIT
+
 /* Number of seconds before entering autoaway and extended autoaway. */
 #define	AWAY_TIME (5*60) 
 #define	EXT_AWAY_TIME (30*60)
@@ -122,8 +127,6 @@ struct _GossipAppPriv {
 	
 	GossipContactList     *contact_list;
 
-	GConfClient           *gconf_client;
-
 	/* Main widgets */
 	GtkWidget             *window;
 	GtkWidget             *main_vbox;
@@ -139,11 +142,8 @@ struct _GossipAppPriv {
 	GtkWidget             *actions_hide_list;
 	GtkWidget             *actions_group_chat_join;   
 
-	/* Accounts toolbar */
-	GtkWidget             *accounts_toolbar;
-
 	/* Tray */
-	EggTrayIcon           *tray_icon;
+	/*EggTrayIcon*/ GtkWidget           *tray_icon;
 	GtkWidget             *tray_event_box;
 	GtkWidget             *tray_image;
 	GList                 *tray_flash_icons;
@@ -263,13 +263,11 @@ static void            app_tray_create                      (void);
 static void            app_tray_update_tooltip              (void);
 static void            app_status_flash_start               (void);
 static void            app_status_flash_stop                (void);
-static void            app_show_offline_key_changed_cb      (GConfClient              *client,
-							     guint                     cnxn_id,
-							     GConfEntry               *entry,
+static void            app_notify_show_offline_cb           (GossipConf               *conf,
+							     const gchar              *key,
  							     gpointer                  check_menu_item);
-static void            app_show_avatars_key_changed_cb      (GConfClient              *client,
-							     guint                     cnxn_id,
-							     GConfEntry               *entry,
+static void            app_notify_show_avatars_cb           (GossipConf               *conf,
+							     const gchar              *key,
 							     gpointer                  user_data);
 static void            app_connect_no_accounts_response_cb  (GtkWidget                *widget,
 							     gint                      response,
@@ -278,33 +276,12 @@ static gboolean        app_idle_check_cb                    (GossipApp
 static void            app_disconnect                       (void);
 static void            app_connection_items_setup           (GladeXML                 *glade);
 static void            app_connection_items_update          (void);
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-static void            app_accounts_account_notify_cb       (GossipAccount            *account,
-							     GParamSpec               *param,
-							     gpointer                  user_data);
-
-static void            app_accounts_account_added_cb        (GossipAccountManager     *manager,
-							     GossipAccount            *account,
-							     gpointer                  user_data);
-static void            app_accounts_account_removed_cb      (GossipAccountManager     *manager,
-							     GossipAccount            *account,
-							     gpointer                  user_data);
-static gint            app_accounts_sort_func               (GossipAccount            *a,
-							     GossipAccount            *b);
-static void            app_accounts_rearrange               (void);
-static void            app_accounts_create                  (void);
-static void            app_accounts_update_separator        (void);
-static void            app_accounts_update_toolbar          (void);
-static void            app_accounts_add                     (GossipAccount            *account);
-static void            app_accounts_remove                  (GossipAccount            *account);
-#else
 static void            app_accounts_error_edit_clicked_cb   (GtkButton                *button,
 							     GossipAccount            *account);
 static void            app_accounts_error_clear_clicked_cb  (GtkButton                *button,
 							     GossipAccount            *account);
 static void            app_accounts_error_display           (GossipAccount            *account,
 							     GError                   *error);
-#endif
 static GossipPresence *app_get_effective_presence           (void);
 static void            app_set_away                         (const gchar              *status);
 static GdkPixbuf *     app_get_current_status_pixbuf        (void);
@@ -322,7 +299,6 @@ static gboolean        configure_event_timeout_cb           (GtkWidget
 static gboolean        app_window_configure_event_cb        (GtkWidget                *widget,
 							     GdkEventConfigure        *event,
 							     GossipApp                *app);
-static gboolean        app_have_tray                        (void);
 static gboolean        app_tray_flash_timeout_func          (gpointer                  data);
 static void            app_tray_flash_start                 (void);
 static void            app_tray_flash_maybe_stop            (void);
@@ -398,25 +374,33 @@ app_finalize (GObject *object)
 	g_list_free (priv->widgets_connected);
 	g_list_free (priv->widgets_disconnected);
 
-	manager = gossip_session_get_account_manager (priv->session);
-
 	if (priv->errors) {
 		g_hash_table_destroy (priv->errors);
 	}
+
+	gtk_widget_destroy (priv->popup_menu);
 	
-	if (priv->tooltips) {
-		g_object_unref (priv->tooltips);
+	g_object_unref (priv->tooltips);
+
+	if (priv->tray_icon) {
+		/* Disconnect so it doesn't get recreated when we destroy it. */
+		g_signal_handlers_disconnect_by_func (priv->tray_icon,
+						      app_tray_destroy_cb,
+						      priv->tray_event_box);
+		
+		gtk_widget_destroy (GTK_WIDGET (priv->tray_icon));
 	}
 
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	g_signal_handlers_disconnect_by_func (manager,
-					      app_accounts_account_added_cb, 
-					      NULL);
-	g_signal_handlers_disconnect_by_func (manager,
-					      app_accounts_account_removed_cb, 
-					      NULL);
+	gossip_conf_shutdown ();
+
+#ifdef HAVE_LIBNOTIFY
+	gossip_notify_finalize ();
 #endif
 
+	gossip_sound_finalize ();
+
+	manager = gossip_session_get_account_manager (priv->session);
+
 	g_signal_handlers_disconnect_by_func (priv->session,
 					      app_session_protocol_connecting_cb, 
 					      NULL);
@@ -444,24 +428,22 @@ app_finalize (GObject *object)
 					      app_event_removed_cb, 
 					      NULL);
 
-	
-	if (priv->event_manager) {
-		g_object_unref (priv->event_manager);
+	if (priv->presence) {
+		g_object_unref (priv->presence);
 	}
 
-	if (priv->chat_manager) {
-		g_object_unref (priv->chat_manager);
+	if (priv->away_presence) {
+		g_object_unref (priv->away_presence);
 	}
 
-	/* call init session dependent modules */
+	g_object_unref (priv->event_manager);
+	g_object_unref (priv->chat_manager);
+	g_object_unref (priv->chatroom_manager);
+	g_object_unref (priv->session);
+
 	gossip_ft_window_finalize (priv->session);
 	gossip_subscription_dialog_finalize (priv->session);
 
-#if 0
- 	gossip_galago_finalize (priv->session); 
-	gossip_dbus_finalize (priv->session); 
-#endif
-
 	G_OBJECT_CLASS (gossip_app_parent_class)->finalize (object);
 }
 
@@ -470,6 +452,7 @@ app_setup (GossipSession        *session,
 	   GossipAccountManager *manager)
 {
         GossipAppPriv  *priv;
+	GossipConf     *conf;
 	GladeXML       *glade;
 	GtkWidget      *sw;
 	GtkWidget      *image;
@@ -486,27 +469,27 @@ app_setup (GossipSession        *session,
 
 	priv = GET_PRIV (app);
 
-	priv->gconf_client = gconf_client_get_default ();
-
-	gconf_client_add_dir (priv->gconf_client,
-			      GCONF_PATH,
-			      GCONF_CLIENT_PRELOAD_ONELEVEL,
-			      NULL);
+	conf = gossip_conf_get ();
 	
 	priv->session = g_object_ref (session);
 
-	/* Call init session dependent modules */
-	gossip_debug (DEBUG_DOMAIN_SETUP, "Initialising session listeners (subscription, file transfer, etc)");
+	gossip_debug (DEBUG_DOMAIN_SETUP,
+		      "Initialising session listeners "
+		      "(subscription, file transfer, etc)");
 	gossip_subscription_dialog_init (priv->session);
 	gossip_ft_window_init (priv->session);
 
-	/* Do we need first time start up druid? */
 	if (gossip_new_account_window_is_needed ()) {
-		gossip_debug (DEBUG_DOMAIN_SETUP, "Showing new account window for first time run");
+		gossip_debug (DEBUG_DOMAIN_SETUP,
+			      "Showing new account window "
+			      "for first time run");
 		gossip_new_account_window_show (NULL);
 	}
 
-	gossip_debug (DEBUG_DOMAIN_SETUP, "Initialising managers (chatroom, chat, event)");
+	gossip_debug (DEBUG_DOMAIN_SETUP,
+		      "Initialising managers "
+		      "(chatroom, chat, event)");
+
 	priv->chatroom_manager = gossip_chatroom_manager_new (manager, 
 							      priv->session, 
 							      NULL);
@@ -514,7 +497,9 @@ app_setup (GossipSession        *session,
 	priv->chat_manager = gossip_chat_manager_new ();
  	priv->event_manager = gossip_event_manager_new (); 
 
-	gossip_debug (DEBUG_DOMAIN_SETUP, "Initialising notification handlers (libnotify, sound)");
+	gossip_debug (DEBUG_DOMAIN_SETUP,
+		      "Initialising notification "
+		      "handlers (libnotify, sound)");
 
 #ifdef HAVE_LIBNOTIFY
 	gossip_notify_init (priv->session, priv->event_manager);
@@ -522,16 +507,6 @@ app_setup (GossipSession        *session,
 
 	gossip_sound_init (priv->session);
 
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	g_signal_connect (manager, "account_added",
-			  G_CALLBACK (app_accounts_account_added_cb), 
-			  NULL);
-
-	g_signal_connect (manager, "account_removed",
-			  G_CALLBACK (app_accounts_account_removed_cb), 
-			  NULL);
-#endif
-
 	g_signal_connect (priv->session, "protocol-connecting",
 			  G_CALLBACK (app_session_protocol_connecting_cb),
 			  NULL);
@@ -569,7 +544,7 @@ app_setup (GossipSession        *session,
 
 	/* set up interface */
 	gossip_debug (DEBUG_DOMAIN_SETUP, "Initialising interface");
-	glade = gossip_glade_get_file (GLADEDIR "/main.glade",
+	glade = gossip_glade_get_file ("main.glade",
 				       "main_window",
 				       NULL,
 				       "main_window", &priv->window,
@@ -580,7 +555,6 @@ app_setup (GossipSession        *session,
 				       "actions_show_offline", &show_offline_widget,
 				       "actions_hide_list", &priv->actions_hide_list,
 				       "actions_group_chat_join", &priv->actions_group_chat_join,
-				       "accounts_toolbar", &priv->accounts_toolbar,
 				       "presence_toolbar", &priv->presence_toolbar,
 				       "roster_scrolledwindow", &sw,
 				       NULL);
@@ -700,14 +674,6 @@ app_setup (GossipSession        *session,
 	gossip_debug (DEBUG_DOMAIN_SETUP, "Configuring accels");
 	app_accels_load ();
 
-	/* Set up accounts area. */
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	gossip_debug (DEBUG_DOMAIN_SETUP, "Configuring accounts toolbar");
-	app_accounts_create ();
-#else
-	gtk_widget_hide (priv->accounts_toolbar);
-#endif
-
 	/* Set the idle time checker. */
 	g_timeout_add (2 * 1000, (GSourceFunc) app_idle_check_cb, app);
 
@@ -736,46 +702,43 @@ app_setup (GossipSession        *session,
 
 	/* Set up 'show_offline' config hooks to know when it changes. */
 	gossip_debug (DEBUG_DOMAIN_SETUP, "Configuring miscellaneous settings");
-	show_offline = gconf_client_get_bool (priv->gconf_client,
-					      GCONF_CONTACTS_SHOW_OFFLINE,
-					      NULL);
-
-	gconf_client_notify_add (priv->gconf_client,
-				 GCONF_CONTACTS_SHOW_OFFLINE,
-				 app_show_offline_key_changed_cb,
-				 show_offline_widget,
-				 NULL, NULL);
+	gossip_conf_get_bool (conf,
+			      GOSSIP_PREFS_CONTACTS_SHOW_OFFLINE,
+			      &show_offline);
+	gossip_conf_notify_add (conf,
+				GOSSIP_PREFS_CONTACTS_SHOW_OFFLINE,
+				app_notify_show_offline_cb,
+				show_offline_widget);
 
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (show_offline_widget),
 					show_offline);
 
 	/* Show avatars? */
-	show_avatars = gconf_client_get_bool (priv->gconf_client,
-					      GCONF_UI_SHOW_AVATARS,
-					      NULL);
-
-	gconf_client_notify_add (priv->gconf_client,
-				 GCONF_UI_SHOW_AVATARS,
-				 app_show_avatars_key_changed_cb,
-				 NULL, NULL, NULL);
+	gossip_conf_get_bool (conf,
+			      GOSSIP_PREFS_UI_SHOW_AVATARS,
+			      &show_avatars);
+	gossip_conf_notify_add (conf,
+				GOSSIP_PREFS_UI_SHOW_AVATARS,
+				app_notify_show_avatars_cb,
+				NULL);
 
 	g_object_set (priv->contact_list, "show-avatars", show_avatars, NULL);
 
-	/* Set window to be hidden / shown. */
-	hidden = gconf_client_get_bool (priv->gconf_client, 
-					GCONF_UI_MAIN_WINDOW_HIDDEN,
-					NULL);
-
-	/* If doesn't have tray, show window and mask "actions_hide_list" */
-	if (!app_have_tray()) {
+	/* Set window to be hidden. If doesn't have tray, show window and mask
+	 * "actions_hide_list".
+	 */
+	if (!gossip_have_tray ()) {
 		hidden = FALSE;
 		gtk_widget_hide (GTK_WIDGET (priv->actions_hide_list));
+	} else {
+		gossip_conf_get_bool (conf,
+				      GOSSIP_PREFS_UI_MAIN_WINDOW_HIDDEN,
+				      &hidden);
 	}
 
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (show_offline_widget),
 					show_offline);
 
- 	/* FIXME: See bug #132632, if (!hidden || !app_have_tray ()) */
  	if (!hidden) {
 		gtk_widget_show (priv->window);
 	} else {
@@ -816,7 +779,7 @@ app_main_window_quit_confirm (GossipApp *app,
 
 		GtkWidget *dialog;
 		gchar     *str;
-		gchar     *oldstr = NULL;
+		gchar     *oldstr;
 
 		str = g_strconcat (_("To summarize:"), "\n", NULL);
 
@@ -833,10 +796,9 @@ app_main_window_quit_confirm (GossipApp *app,
 
 			count[type]++;
 		}
-		
+
+		str = g_strdup ("");
 		for (i = 0; i < GOSSIP_EVENT_ERROR; i++) {
-			gchar *str_single = NULL;
-			gchar *str_plural = NULL;
 			gchar *info;
 			gchar *format;
 
@@ -846,38 +808,41 @@ app_main_window_quit_confirm (GossipApp *app,
 			
 			switch (i) {
 			case GOSSIP_EVENT_NEW_MESSAGE: 
-				str_single = "%d New message";
-				str_plural = "%d New messages";
+				format = ngettext ("%d new message",
+						   "%d new messages",
+						   count[i]);
 				break;
 			case GOSSIP_EVENT_SUBSCRIPTION_REQUEST: 
-				str_single = "%d Subscription request";
-				str_plural = "%d Subscription requests";
+				format = ngettext ("%d subscription request",
+						   "%d subscription requests",
+						   count[i]);
 				break;
 			case GOSSIP_EVENT_FILE_TRANSFER_REQUEST: 
-				str_single = "%d File transfer request";
-				str_plural = "%d File transfer requests";
+				format = ngettext ("%d file transfer request",
+						   "%d file transfer requests",
+						   count[i]);
 				break;
 			case GOSSIP_EVENT_SERVER_MESSAGE: 
-				str_single = "%d Server message";
-				str_plural = "%d Server messages";
+				format = ngettext ("%d server message",
+						   "%d server messages",
+						   count[i]);
 				break;
 			case GOSSIP_EVENT_ERROR: 
-				str_single = "%d Error";
-				str_plural = "%d Errors";
+				format = ngettext ("%d error",
+						   "%d errors",
+						   count[i]);
+				break;
+			default:
+				format = "";
 				break;
 			}
 
-			format = ngettext (str_single, str_plural, count[i]);
 			info = g_strdup_printf (format, count[i]);
 
-			if (oldstr) {
-				g_free (oldstr);
-			}
-
 			oldstr = str;
-
-			str = g_strconcat (str, "\n", "\t", info, NULL);
+			str = g_strconcat (str, info, "\n",NULL);
 			g_free (info);
+			g_free (oldstr);
 		}
 
 		g_list_free (events);
@@ -897,15 +862,14 @@ app_main_window_quit_confirm (GossipApp *app,
 		
 		gtk_widget_show (dialog);
 
+		g_free (str);
+		
 		return TRUE;
 	}
 
 	return FALSE;
 }
 
-/*
- * window signals
- */
 static void
 app_main_window_quit_confirm_cb (GtkWidget *dialog,
 				 gint       response,
@@ -937,7 +901,11 @@ app_main_window_destroy_cb (GtkWidget *window,
 	/* Save user-defined accelerators. */
 	app_accels_save ();
 
+#ifdef DEBUG_QUIT
+	gtk_main_quit ();
+#else	
 	exit (EXIT_SUCCESS);
+#endif
 }
 
 static gboolean
@@ -1064,18 +1032,14 @@ app_show_offline_cb (GtkCheckMenuItem *item,
 
 	current = gtk_check_menu_item_get_active (item);
 
-	gconf_client_set_bool (priv->gconf_client,
-			       GCONF_CONTACTS_SHOW_OFFLINE,
-			       current,
-			       NULL);
-
-	/* turn off while we alter the contact list */
-	gossip_sound_toggle (FALSE);
-
+	gossip_conf_set_bool (gossip_conf_get (),
+			       GOSSIP_PREFS_CONTACTS_SHOW_OFFLINE,
+			       current);
+	
+	/* Turn off sound just while we alter the contact list. */
+	gossip_sound_set_enabled (FALSE);
 	g_object_set (priv->contact_list, "show_offline", current, NULL);
-
-	/* turn on back to normal */
-	gossip_sound_toggle (TRUE);
+	gossip_sound_set_enabled (TRUE);
 }
 
 static void
@@ -1118,36 +1082,9 @@ static void
 app_help_cb (GtkWidget *window,
 	     GossipApp *app)
 {
-	gboolean   ok;
-
-	GtkWidget *dialog;
-	GError    *err = NULL;
-
-	ok = gnome_help_display ("gossip.xml", NULL, &err);
-	if (ok) {
-		return;
-	}
-
-	dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (gossip_app_get_window ()),
-						     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_MESSAGE_ERROR,
-						     GTK_BUTTONS_CLOSE,
-						     "<b>%s</b>\n\n%s",
-						     _("Could not display the help contents."),
-						     err->message);
-	
-	g_signal_connect_swapped (dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  dialog);
-
-	gtk_widget_show (dialog);
-		
-	g_error_free (err);
+	gossip_help_show ();
 }
 
-/* 
- * libgossip signals 
- */
 static gboolean
 app_throbber_button_press_event_cb (GtkWidget      *throbber,
 				    GdkEventButton *event,
@@ -1205,10 +1142,12 @@ app_session_protocol_connected_cb (GossipSession  *session,
 	g_hash_table_remove (priv->errors, account);
 
 	app_connection_items_update ();
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	app_accounts_update_toolbar ();
-#endif
 	app_chatroom_favourite_update ();
+
+	/* Use saved presence */
+	gossip_app_set_presence (gossip_status_presets_get_default_state (), 
+				 gossip_status_presets_get_default_status());
+
 	app_presence_updated ();
 }
 
@@ -1236,9 +1175,6 @@ app_session_protocol_disconnected_cb (GossipSession  *session,
 	}
 
  	app_connection_items_update ();
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	app_accounts_update_toolbar ();
-#endif
 	app_chatroom_favourite_update ();
 	app_presence_updated ();
 }
@@ -1250,13 +1186,6 @@ app_session_protocol_error_cb (GossipSession  *session,
 			       GError         *error,
 			       gpointer        user_data)
 {
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-	GossipAppPriv *priv;
-
-	priv = GET_PRIV (app);
-
-	gtk_widget_show (priv->accounts_toolbar);
-#else
 	GossipAppPriv *priv;
 	gboolean       connecting;
 
@@ -1275,7 +1204,6 @@ app_session_protocol_error_cb (GossipSession  *session,
 	}
 
 	app_accounts_error_display (account, error);	
-#endif
 }
 
 static gchar * 
@@ -1300,23 +1228,15 @@ app_session_get_password_cb (GossipSession *session,
 static void
 app_accels_load (void)
 {
-	gchar *dir;
-	gchar *file_with_path;
+	gchar *filename;
 
-	dir = g_build_filename (g_get_home_dir (), ".gnome2", PACKAGE_NAME, NULL);
-	if (!g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		g_mkdir_with_parents (dir, S_IRUSR | S_IWUSR | S_IXUSR);
-	}
-
-	file_with_path = g_build_filename (dir, ACCELS_FILENAME, NULL);
-	g_free (dir);
-
-	if (g_file_test (file_with_path, G_FILE_TEST_EXISTS)) {
-		gossip_debug (DEBUG_DOMAIN_ACCELS, "Loading from:'%s'", file_with_path);
-		gtk_accel_map_load (file_with_path);
+	filename = g_build_filename (g_get_home_dir (), ".gnome2", PACKAGE_NAME, ACCELS_FILENAME, NULL);
+	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		gossip_debug (DEBUG_DOMAIN_ACCELS, "Loading from:'%s'", filename);
+		gtk_accel_map_load (filename);
 	}
 	
-	g_free (file_with_path);
+	g_free (filename);
 }
 
 static void
@@ -1326,10 +1246,7 @@ app_accels_save (void)
 	gchar *file_with_path;
 
 	dir = g_build_filename (g_get_home_dir (), ".gnome2", PACKAGE_NAME, NULL);
-	if (!g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		g_mkdir_with_parents (dir, S_IRUSR | S_IWUSR | S_IXUSR);
-	}
-
+	g_mkdir_with_parents (dir, S_IRUSR | S_IWUSR | S_IXUSR);
 	file_with_path = g_build_filename (dir, ACCELS_FILENAME, NULL);
 	g_free (dir);
 
@@ -1339,10 +1256,6 @@ app_accels_save (void)
 	g_free (file_with_path);
 }
 
-/*
- * Notification area signals
- */
-
 gboolean
 gossip_app_is_window_visible (void)
 {
@@ -1363,7 +1276,7 @@ gossip_app_toggle_visibility (void)
 
 	visible = gossip_window_get_is_visible (GTK_WINDOW (priv->window));
 
-	if (visible && app_have_tray()) {
+	if (visible && gossip_have_tray ()) {
 		gint x, y, w, h;
 
 		gtk_window_get_size (GTK_WINDOW (priv->window), &w, &h);
@@ -1378,9 +1291,8 @@ gossip_app_toggle_visibility (void)
 
 		gtk_widget_hide (priv->window);
 		
-		gconf_client_set_bool (priv->gconf_client, 
-				       GCONF_UI_MAIN_WINDOW_HIDDEN, TRUE,
-				       NULL);
+		gossip_conf_set_bool (gossip_conf_get (),
+				       GOSSIP_PREFS_UI_MAIN_WINDOW_HIDDEN, TRUE);
 	} else {
 		gint x, y, w, h;
 
@@ -1402,9 +1314,8 @@ gossip_app_toggle_visibility (void)
 
 		gossip_window_present (GTK_WINDOW (priv->window));
 
-		gconf_client_set_bool (priv->gconf_client, 
-				       GCONF_UI_MAIN_WINDOW_HIDDEN, FALSE,
-				       NULL);
+		gossip_conf_set_bool (gossip_conf_get (),
+				       GOSSIP_PREFS_UI_MAIN_WINDOW_HIDDEN, FALSE);
 	}
 }
 
@@ -1422,7 +1333,6 @@ gossip_app_set_visibility (gboolean visible)
 	}
 }
 
-
 static void
 app_show_hide_list_cb (GtkWidget *widget,
 		       GossipApp *app)
@@ -1458,7 +1368,7 @@ app_tray_destroy_cb (GtkWidget *widget,
 	app_tray_create ();
 	
 	/* Show the window in case the notification area was removed */
-	if (!app_have_tray ()) {
+	if (!gossip_have_tray ()) {
 		gtk_widget_show (priv->window);
 	}
 
@@ -1530,7 +1440,7 @@ app_tray_create_menu (void)
 
 	priv = GET_PRIV (app);
 
-	glade = gossip_glade_get_file (GLADEDIR "/main.glade",
+	glade = gossip_glade_get_file ("main.glade",
 				       "tray_menu",
 				       NULL,
 				       "tray_menu", &priv->popup_menu,
@@ -1560,6 +1470,7 @@ app_tray_create_menu (void)
 static void
 app_tray_create (void)
 {
+#ifdef HAVE_GNOME
 	GossipAppPriv *priv;
 	GdkPixbuf     *pixbuf;
 	gchar         *name;
@@ -1567,7 +1478,7 @@ app_tray_create (void)
 	priv = GET_PRIV (app);
 
 	name = g_strdup_printf ("%s, Instant Messaging Client", PACKAGE_NAME);
-	priv->tray_icon = egg_tray_icon_new (name);
+	priv->tray_icon = GTK_WIDGET (egg_tray_icon_new (name));
 	g_free (name);
 
 	priv->tray_event_box = gtk_event_box_new ();
@@ -1606,6 +1517,11 @@ app_tray_create (void)
 #endif
 
 	app_tray_update_tooltip ();
+#else
+	if (0) {
+		app_tray_button_press_cb (NULL, NULL, NULL);
+	}
+#endif
 }
 
 static void
@@ -1634,19 +1550,23 @@ app_tray_update_tooltip (void)
 			status = _("Disconnected");
 		}
 
-		gtk_tooltips_set_tip (GTK_TOOLTIPS (priv->tooltips),
-				      priv->tray_event_box, status, status);
-
+		if (priv->tray_event_box) {
+			gtk_tooltips_set_tip (GTK_TOOLTIPS (priv->tooltips),
+					      priv->tray_event_box, status, status);
+		}
+		
 		return;
 	}
 
 	event = priv->tray_flash_icons->data;
 
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (priv->tooltips),
-			      priv->tray_event_box,
-			      gossip_event_get_message (event),
-			      gossip_event_get_message (event));
-}	
+	if (priv->tray_event_box) {
+		gtk_tooltips_set_tip (GTK_TOOLTIPS (priv->tooltips),
+				      priv->tray_event_box,
+				      gossip_event_get_message (event),
+				      gossip_event_get_message (event));
+	}	
+}
 
 static void
 app_status_flash_start (void)
@@ -1654,7 +1574,7 @@ app_status_flash_start (void)
 	GossipAppPriv *priv;
 	
 	priv = GET_PRIV (app);
-	
+
 	gossip_presence_chooser_flash_start (GOSSIP_PRESENCE_CHOOSER (priv->presence_chooser),
 					     app_get_current_state (),
 					     app_get_previous_state ());
@@ -1675,41 +1595,34 @@ app_status_flash_stop (void)
 	app_tray_flash_maybe_stop ();
 }
 
-/*
- * gconf signals
- */
 static void
-app_show_offline_key_changed_cb (GConfClient *client,
-				 guint        cnxn_id,
-				 GConfEntry  *entry,
-				 gpointer     check_menu_item)
+app_notify_show_offline_cb (GossipConf  *conf,
+			    const gchar *key,
+			    gpointer     check_menu_item)
 {
 	gboolean show_offline;
 
-	show_offline = gconf_value_get_bool (gconf_entry_get_value (entry));
-
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (check_menu_item),
-					show_offline);
+	if (gossip_conf_get_bool (conf, key, &show_offline)) {
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (check_menu_item),
+						show_offline);
+	}
 }
 
 static void
-app_show_avatars_key_changed_cb (GConfClient *client,
-				 guint        cnxn_id,
-				 GConfEntry  *entry,
-				 gpointer     user_data)
+app_notify_show_avatars_cb (GossipConf  *conf,
+			    const gchar *key,
+			    gpointer     user_data)
 {
 	GossipAppPriv *priv;
 	gboolean       show_avatars;
 
 	priv = GET_PRIV (app);
 
-	show_avatars = gconf_value_get_bool (gconf_entry_get_value (entry));
-	gossip_contact_list_set_show_avatars (priv->contact_list, show_avatars);
+	if (gossip_conf_get_bool (conf, key, &show_avatars)) {
+		gossip_contact_list_set_show_avatars (priv->contact_list, show_avatars);
+	}
 }
 
-/*
- * misc signals
- */
 static gboolean
 app_idle_check_cb (GossipApp *app)
 {
@@ -1867,10 +1780,10 @@ gossip_app_net_down (void)
 
 	priv = GET_PRIV (app);
 
-	/* Disconnect all and store a list */
+	/* Disconnect all and store a list. */
 	accounts = gossip_session_get_accounts (priv->session);
 	for (l = accounts; l; l = l->next) {
-		GossipAccount *account = GOSSIP_ACCOUNT (l->data);
+		GossipAccount *account = l->data;
 
 		if (!gossip_session_is_connected (priv->session, account)) {
 			continue;
@@ -1882,7 +1795,7 @@ gossip_app_net_down (void)
 		gossip_session_disconnect (priv->session, account);
 	}
 
-	g_list_foreach (accounts, (GFunc)g_object_unref, NULL);
+	g_list_foreach (accounts, (GFunc) g_object_unref, NULL);
 	g_list_free (accounts);
 }
 
@@ -1894,17 +1807,17 @@ gossip_app_net_up (void)
 
 	priv = GET_PRIV (app);
 
-	/* Connect all that went down before */
+	/* Connect all that went down before. */
 	if (!tmp_account_list) {
 		/* If no previous disconnect then we just 
-		 * connect the default connect on startup accounts
+		 * connect the default connect on startup accounts.
 		 */
 		gossip_app_connect (NULL, TRUE);
 		return;
 	}
 
 	for (l = tmp_account_list; l; l = l->next) {
-		GossipAccount *account = GOSSIP_ACCOUNT (l->data);
+		GossipAccount *account = l->data;
 		
 		gossip_session_connect (priv->session, account, FALSE);
 		g_object_unref (account);
@@ -2179,301 +2092,6 @@ app_accounts_error_display (GossipAccount *account,
 	g_hash_table_insert (priv->errors, g_object_ref (account), child);
 }
 
-#ifdef USE_ORIGINAL_TOOLBAR_CODE
-
-static void
-app_accounts_account_notify_cb (GossipAccount *account,
-				GParamSpec    *param,
-				gpointer       user_data)
-{
-	app_accounts_rearrange ();
-}
-
-static void
-app_accounts_account_added_cb (GossipAccountManager *manager,
-			       GossipAccount        *account,
-			       gpointer              user_data)
-{
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Account added");
-	app_accounts_rearrange ();
-	app_connection_items_update ();
-}
-
-static void
-app_accounts_account_removed_cb (GossipAccountManager *manager,
-				 GossipAccount        *account,
-				 gpointer              user_data)
-{
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Account removed");
-	app_accounts_remove (account);
-	app_connection_items_update ();
-}
-
-static gint
-app_accounts_sort_func (GossipAccount *a, 
-			GossipAccount *b)
-{
-	gboolean     auto_connect_a;
-	gboolean     auto_connect_b;
-	const gchar *name_a;
-	const gchar *name_b;
-
-	auto_connect_a = gossip_account_get_auto_connect (a);
-	auto_connect_b = gossip_account_get_auto_connect (b);
-	
-	if (auto_connect_a && !auto_connect_b) {
-		return -1;
-	}
-
-	if (!auto_connect_a && auto_connect_b) {
-		return 1;
-	}
-
-	/* after this, we strcmp based on name */
-	name_a = gossip_account_get_name (a);
-	name_b = gossip_account_get_name (b);
-
-	if (name_a && !name_b) {
-		return -1;
-	}
-
-	if (!name_a && name_b) {
-		return 1;
-	}
-
-	return strcmp (name_a, name_b);
-}
-
-static void
-app_accounts_rearrange (void)
-{
-	GossipAppPriv *priv;
-	GList         *children;
-	GList         *l;
-
-	priv = GET_PRIV (app);
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Rearranging toolbar");
-
-	/* Remove all children for a reshuffle */
-	children = gtk_container_get_children (GTK_CONTAINER (priv->accounts_toolbar));
-	for (l = children; l; l = l->next) {
-		gtk_container_remove (GTK_CONTAINER (priv->accounts_toolbar), l->data);
-	}
-	
-	g_list_free (children);
-
-	/* Add accounts back in */
-	app_accounts_create ();
-}
-
-static void
-app_accounts_create (void)
-{
-	GossipAppPriv        *priv;
-	GossipAccountManager *manager;
-	GList                *accounts;
-	GList                *l;
-
-	priv = GET_PRIV (app);
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Creating toolbar");
-
-	manager = gossip_session_get_account_manager (priv->session);
-	accounts = gossip_account_manager_get_accounts (manager);
-
-	/* Add enabled accounts first, since they are important, they
-	 * should be at the start of the account list.
-	 */
-	accounts = g_list_sort (accounts, (GCompareFunc) app_accounts_sort_func);
-
-	for (l = accounts; l; l = l->next) {
-		app_accounts_add (GOSSIP_ACCOUNT (l->data));
-	}
-
-	g_list_free (accounts);
-
-	/* Update separator position */
-	app_accounts_update_separator ();
-}
-
-static void
-app_accounts_update_separator (void)
-{
-	GossipAppPriv *priv;
-	GtkToolItem   *item;
-	GList         *children;
-	GList         *l;
-	gint           index = 0;
-
-	priv = GET_PRIV (app);
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Updating toolbar separator position");
-
-	/* Remove current separator */
-	children = gtk_container_get_children (GTK_CONTAINER (priv->accounts_toolbar));
-	for (l = children; l; l = l->next) {
-		if (G_OBJECT_TYPE (l->data) == GOSSIP_TYPE_ACCOUNT_BUTTON) {
-			continue;
-		}
-
-		gtk_container_remove (GTK_CONTAINER (priv->accounts_toolbar), l->data);
-	}
-	
-	g_list_free (children);
-
-	/* Find position for new separator */
-	children = gtk_container_get_children (GTK_CONTAINER (priv->accounts_toolbar));
-	for (l = children; l; l = l->next) {
-		GossipAccountButton *account_button;
-
-		account_button = l->data;
-
-		if (gossip_account_button_is_important (account_button)) {
-			index++;
-		} else {
-			break;
-		}
-	}
-
-	/* Don't put a separator in if it is at the start or end */
-	if (index > 0 && index < g_list_length (children)) {
-		/* Create separator */
-		item = gtk_separator_tool_item_new ();
-		gtk_toolbar_insert (GTK_TOOLBAR (priv->accounts_toolbar), item, index);
-		gtk_widget_show (GTK_WIDGET (item));
-	}
-
-	g_list_free (children);
-}
-
-static void 
-app_accounts_update_toolbar (void)
-{
-	GossipAppPriv *priv;
-	GList         *children;
-	GList         *l;
-	gint           count;
-	gboolean       errors;              
-
-	priv = GET_PRIV (app);
-
-	/* Find position for new separator */
-	children = gtk_container_get_children (GTK_CONTAINER (priv->accounts_toolbar));
-	for (l = children, errors = FALSE; l && !errors; l = l->next) {
-		GossipAccountButton *account_button;
-
-		if (G_OBJECT_TYPE (l->data) != GOSSIP_TYPE_ACCOUNT_BUTTON) {
-			continue;
-		}
-
-		account_button = l->data;
-
-		if (gossip_account_button_is_error_shown (account_button)) {
-			errors = TRUE;
-		}
-	}
-
-	count = g_list_length (children);
-
-	/* Show accounts if we have more than one */
-	if (count < 2 || errors) {
-		gtk_widget_hide (priv->accounts_toolbar);
-	} else {
-		gtk_widget_show (priv->accounts_toolbar);
-	}
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "There are %d accounts on the toolbar", count);
-
-	g_list_free (children);
-}
-
-static void
-app_accounts_add (GossipAccount *account)
-{
-	GossipAppPriv *priv;
-	GtkWidget     *account_button;
-	gboolean       connected;
-
-	priv = GET_PRIV (app);
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Adding account with id:'%s'", 
-		      gossip_account_get_id (account));
-
-	account_button = gossip_account_button_new ();
-	gossip_account_button_set_account (GOSSIP_ACCOUNT_BUTTON (account_button), 
-					   account);
-
-	connected = gossip_session_is_connected (priv->session, account);
-	gossip_account_button_set_status (GOSSIP_ACCOUNT_BUTTON (account_button), 
-					  connected);
-
-	/* disconnect any handlers already set up to do this */
-	g_signal_handlers_disconnect_by_func (account,
-					      G_CALLBACK (app_accounts_account_notify_cb), 
-					      NULL);
-
-	g_signal_connect (account, "notify", 
-			  G_CALLBACK (app_accounts_account_notify_cb), 
-			  NULL);
-
-	/* Add to toolbar. */
-	gtk_container_add (GTK_CONTAINER (priv->accounts_toolbar), account_button);
-	gtk_widget_show_all (account_button);
-
-	/* Show/hide toolbar. */
-	app_accounts_update_toolbar ();
-}
-
-static void
-app_accounts_remove (GossipAccount *account)
-{
-	GossipAppPriv *priv;
-	GtkContainer  *container;
-	GList         *children;
-	GList         *l;
-	gboolean       remove_separator;
-
-	priv = GET_PRIV (app);
-
-	gossip_debug (DEBUG_DOMAIN_ACCOUNTS, "Removing account with id:'%s'", 
-		      gossip_account_get_id (account));
-
-	container = GTK_CONTAINER (priv->accounts_toolbar);
-	children = gtk_container_get_children (container);
-	remove_separator = g_list_length (children) == 3;
-
-	for (l = children; l; l = l->next) {
-		GossipAccount *this_account;
-
-		if (G_OBJECT_TYPE (l->data) != GOSSIP_TYPE_ACCOUNT_BUTTON) {
-			if (remove_separator) {
-				gtk_container_remove (container, l->data);
-			}
-
-			continue;
-		}
-		
-		this_account = gossip_account_button_get_account (l->data);
-		if (!gossip_account_equal (account, this_account)) {
-			continue;
-		}
-
-		g_signal_handlers_disconnect_by_func (account,
-						      G_CALLBACK (app_accounts_account_notify_cb), 
-						      NULL);
-		
-		gtk_container_remove (container, l->data);
-	}
-	
-	g_list_free (children);
-
-	/* Show/hide toolbar */
-	app_accounts_update_toolbar ();
-}
-
-#endif /* USE_ORIGINAL_TOOLBAR_CODE */
-
 static GossipPresence *
 app_get_effective_presence (void)
 {
@@ -2567,11 +2185,11 @@ app_presence_updated (void)
 	
 	priv = GET_PRIV (app);
 
-	pixbuf = app_get_current_status_pixbuf ();
-
-	gtk_image_set_from_pixbuf (GTK_IMAGE (priv->tray_image), pixbuf);
-	
-	g_object_unref (pixbuf);
+	if (priv->tray_image) {
+		pixbuf = app_get_current_status_pixbuf ();
+		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->tray_image), pixbuf);
+		g_object_unref (pixbuf);
+	}
 	
 	if (!gossip_session_is_connected (priv->session, NULL)) {
 		gossip_presence_chooser_set_status (
@@ -2651,14 +2269,14 @@ gossip_app_set_presence (GossipPresenceState  state,
 		 * across two Gossips.
 		 */
 		default_status = gossip_presence_state_get_default_status (state);
-		if (strcmp (status, default_status) == 0) {
-			status = NULL;
+
+		if (status && strcmp (status, default_status) == 0) {
+			g_object_set (priv->presence, "status", NULL, NULL);
+		} else {
+			g_object_set (priv->presence, "status", status, NULL);
 		}
 		
-		g_object_set (priv->presence,
-			      "state", state,
-			      "status", status,
-			      NULL);
+		g_object_set (priv->presence, "state", state, NULL);
 
 		app_status_flash_stop ();
 		app_status_clear_away ();
@@ -2676,6 +2294,7 @@ app_presence_chooser_changed_cb (GtkWidget           *chooser,
 				 gpointer             user_data)
 {
 	gossip_app_set_presence (state, status);
+	gossip_status_presets_set_default (state, status);
 }
 
 static gboolean
@@ -2687,7 +2306,7 @@ configure_event_timeout_cb (GtkWidget *widget)
 	priv = GET_PRIV (app);
 
 	gtk_window_get_size (GTK_WINDOW (widget), &w, &h);
-	gtk_window_get_position (GTK_WINDOW (priv->window), &x, &y);
+	gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
 
 	gossip_geometry_save_for_main_window (x, y, w, h);
 
@@ -2726,35 +2345,6 @@ gossip_app_get_window (void)
 	return priv->window;
 }
 
-GConfClient *
-gossip_app_get_gconf_client (void)
-{
-	GossipAppPriv *priv;
-
-	priv = GET_PRIV (app);
-
-	return priv->gconf_client;
-}
-
-static gboolean
-app_have_tray (void)
-{
-	Screen *xscreen = DefaultScreenOfDisplay (gdk_display);
-	Atom    selection_atom;
-	char   *selection_atom_name;
-	
-	selection_atom_name = g_strdup_printf ("_NET_SYSTEM_TRAY_S%d",
-					       XScreenNumberOfScreen (xscreen));
-	selection_atom = XInternAtom (DisplayOfScreen (xscreen), selection_atom_name, False);
-	g_free (selection_atom_name);
-	
-	if (XGetSelectionOwner (DisplayOfScreen (xscreen), selection_atom)) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
 static gboolean
 app_tray_flash_timeout_func (gpointer data)
 {
@@ -2765,6 +2355,10 @@ app_tray_flash_timeout_func (gpointer data)
 
 	priv = GET_PRIV (app);
 
+	if (!priv->tray_image) {
+		return TRUE;
+	}
+	
 	is_flashing = gossip_presence_chooser_is_flashing
 		(GOSSIP_PRESENCE_CHOOSER (priv->presence_chooser));
 
@@ -2835,9 +2429,11 @@ app_tray_flash_maybe_stop (void)
 		return;
 	}
 
-	pixbuf = app_get_current_status_pixbuf ();
-	gtk_image_set_from_pixbuf (GTK_IMAGE (priv->tray_image), pixbuf);
-	g_object_unref (pixbuf);
+	if (priv->tray_image) {
+		pixbuf = app_get_current_status_pixbuf ();
+		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->tray_image), pixbuf);
+		g_object_unref (pixbuf);
+	}
 	
 	if (priv->tray_flash_timeout_id) {
 		g_source_remove (priv->tray_flash_timeout_id);
@@ -2894,7 +2490,7 @@ app_chatroom_favourite_update (void)
 		return;
 	}
 
-	g_list_foreach (accounts, (GFunc)g_object_unref, NULL);
+	g_list_foreach (accounts, (GFunc) g_object_unref, NULL);
 	g_list_free (accounts);
 
 	chatrooms = gossip_chatroom_manager_get_chatrooms (priv->chatroom_manager, NULL);
@@ -2913,7 +2509,7 @@ app_chatroom_favourite_update (void)
 		if (!gossip_session_is_connected (priv->session, account)) {
 			continue;
 		}
-
+		
 		/* If we find at least ONE chatroom that is a
 		 * favourite on an account that _IS_ connected, we
 		 * make the join favourites option available.
@@ -2943,10 +2539,10 @@ app_event_added_cb (GossipEventManager *manager,
 	GossipAppPriv *priv;
 	GList         *l;
 		
-	gossip_debug (DEBUG_DOMAIN_TRAY, "Start blink");
-
 	priv = GET_PRIV (app);
 	
+	gossip_request_user_attention ();
+	
 	l = g_list_find_custom (priv->tray_flash_icons, 
 				event, gossip_event_compare);
 	if (l) {
@@ -2971,13 +2567,11 @@ app_event_removed_cb (GossipEventManager *manager,
 
 	priv = GET_PRIV (app);
 
-	gossip_debug (DEBUG_DOMAIN_TRAY, "Stop blink");
 	l = g_list_find_custom (priv->tray_flash_icons, event,
 				gossip_event_compare);
 
 	if (!l) {
 		/* Not flashing this event */
-		gossip_debug (DEBUG_DOMAIN_TRAY, "Couldn't find event");
 		return;
 	}
 
@@ -3004,7 +2598,6 @@ app_contact_activated_cb (GossipContactList *contact_list,
 		return;
 	}
 
-	/* Default to starting chat */
 	gossip_chat_manager_show_chat (priv->chat_manager, contact);
 }
 
