@@ -22,13 +22,10 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <loudmouth/loudmouth.h>
 
 #include "gossip-app.h"
 #include "gossip-edit-groups-dialog.h"
 
-#define d(x)
-
 
 struct _GossipEditGroups {
 	GtkWidget   *dialog;
@@ -136,7 +133,7 @@ gossip_edit_groups_new (GossipContact *contact)
         info->contact = g_object_ref (contact);
         groups = gossip_contact_get_groups (contact);
         
-	gui = gossip_glade_get_file (GLADEDIR "/main.glade",
+	gui = gossip_glade_get_file ("main.glade",
 				     "edit_groups_dialog",
 				     NULL,
 				     "edit_groups_dialog", &info->dialog,
@@ -316,14 +313,14 @@ edit_groups_add_groups (GossipEditGroups *info, GList *groups)
 				gtk_list_store_set (store, &iter,    
 						    COL_ENABLED, TRUE,
 						    -1);
-			} else {
-				d (g_assert_not_reached ());
 			}
 		}
 	}
 
 	g_list_foreach (my_groups, (GFunc) g_free, NULL); 
 	g_list_free (my_groups);
+
+	g_list_free (all_groups);
 }
 
 static gboolean 
