@@ -23,18 +23,19 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 
 #ifdef HAVE_ASPELL
 #include <aspell.h>
 #endif
 
+#include <libgossip/gossip-debug.h>
+#include <libgossip/gossip-conf.h>
+
 #include "gossip-spell.h"
 #include "gossip-app.h"
 #include "gossip-preferences.h"
 
-#define DEBUG_MSG(x)  
-/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");   */
+#define DEBUG_DOMAIN "Spell"
 
 #ifdef HAVE_ASPELL
 
@@ -48,15 +49,12 @@ typedef struct {
         AspellSpeller      *spell_checker;
 } SpellLanguage;
 
-
 #define ISO_CODES_DATADIR    ISO_CODES_PREFIX "/share/xml/iso-codes"
 #define ISO_CODES_LOCALESDIR ISO_CODES_PREFIX "/share/locale"
 
-
 static GHashTable  *iso_code_names = NULL;
 static GList       *languages = NULL;
-static gboolean     gconf_notify_inited = FALSE;
-
+static gboolean     gossip_conf_notify_inited = FALSE;
 
 static void
 spell_iso_codes_parse_start_tag (GMarkupParseContext  *ctx,
@@ -134,7 +132,7 @@ spell_iso_code_names_init (void)
 	gsize   buf_len;
 
 	iso_code_names = g_hash_table_new_full (g_str_hash, g_str_equal,
-					   g_free, g_free);
+						g_free, g_free);
 
 	bindtextdomain ("iso_639", ISO_CODES_LOCALESDIR);
 	bind_textdomain_codeset ("iso_639", "UTF-8");
@@ -165,13 +163,14 @@ spell_iso_code_names_init (void)
 }
 
 static void
-spell_languages_notify_cb (GConfClient *client,
-			   guint        cnxn_id,
-			   GConfEntry  *entry,
+spell_notify_languages_cb (GossipConf  *conf,
+			   const gchar *key,
 			   gpointer     user_data)
 {
 	GList *l;
-	
+
+	gossip_debug (DEBUG_DOMAIN, "Resetting languages due to config change");
+
 	/* We just reset the languages list. */
 	for (l = languages; l; l = l->next) {
 		SpellLanguage *lang;
@@ -193,31 +192,32 @@ spell_setup_languages (void)
 {
 	gchar  *str;
 
-	if (!gconf_notify_inited) {
-		gconf_client_notify_add (gossip_app_get_gconf_client (),
-					 GCONF_CHAT_SPELL_CHECKER_LANGUAGES,
-					 spell_languages_notify_cb,
-					 NULL, NULL, NULL);
+	if (!gossip_conf_notify_inited) {
+		gossip_conf_notify_add (gossip_conf_get (),
+					 GOSSIP_PREFS_CHAT_SPELL_CHECKER_LANGUAGES,
+					 spell_notify_languages_cb, NULL);
 		
-		gconf_notify_inited = TRUE;
+		gossip_conf_notify_inited = TRUE;
 	}
 	
 	if (languages) {
+		gossip_debug (DEBUG_DOMAIN, "No languages to setup");
 		return;
 	}
 
-	str = gconf_client_get_string (gossip_app_get_gconf_client (),
-				       GCONF_CHAT_SPELL_CHECKER_LANGUAGES,
-				       NULL);
-	if (str) {
+	if (gossip_conf_get_string (gossip_conf_get (),
+				     GOSSIP_PREFS_CHAT_SPELL_CHECKER_LANGUAGES,
+				     &str) && str) {
 		gchar **strv;
 		gint    i;
-
+		
 		strv = g_strsplit (str, ",", -1);
 
 		i = 0;
 		while (strv && strv[i]) {
 			SpellLanguage *lang;
+
+			gossip_debug (DEBUG_DOMAIN, "Setting up language:'%s'", strv[i]);
 			
 			lang = g_new0 (SpellLanguage, 1);
 		
@@ -230,17 +230,19 @@ spell_setup_languages (void)
 		
 			if (aspell_error_number (lang->spell_possible_err) == 0) {
 				lang->spell_checker = to_aspell_speller (lang->spell_possible_err);
+				languages = g_list_append (languages, lang);
+			} else {
+				delete_aspell_config (lang->spell_config);
+				g_free (lang);
 			}
-		
-			languages = g_list_append (languages, lang);
 		}
 		
 		if (strv) {
 			g_strfreev (strv);
 		}
-	}
 
-	g_free (str);
+		g_free (str);
+	}
 }
 
 const char *
@@ -311,6 +313,11 @@ gossip_spell_check (const gchar *word)
 
 	spell_setup_languages ();
 
+	if (!languages) {
+		gossip_debug (DEBUG_DOMAIN, "No languages to check against");
+		return TRUE;
+	}
+
 	/* Ignore certain cases like numbers, etc. */
 	for (p = word, digit = TRUE; *p && digit; p = g_utf8_next_char (p)) {
 		c = g_utf8_get_char (p);
@@ -319,7 +326,7 @@ gossip_spell_check (const gchar *word)
 
 	if (digit) {
 		/* We don't spell check digits. */
-		DEBUG_MSG (("Not spell checking word:'%s', it is all digits", word));
+		gossip_debug (DEBUG_DOMAIN, "Not spell checking word:'%s', it is all digits", word);
 		return TRUE;
 	}
 		
@@ -379,9 +386,12 @@ gboolean
 gossip_spell_supported (void)
 {
 	if (g_getenv ("GOSSIP_SPELL_DISABLED")) {
+		gossip_debug (DEBUG_DOMAIN, "GOSSIP_SPELL_DISABLE env variable defined");
 		return FALSE;
 	}
 
+	gossip_debug (DEBUG_DOMAIN, "Support enabled");
+
 	return TRUE;
 }
 
@@ -390,30 +400,40 @@ gossip_spell_supported (void)
 gboolean
 gossip_spell_supported (void)
 {
+	gossip_debug (DEBUG_DOMAIN, "Support disabled");
+
 	return FALSE;
 }
 
 GList *
 gossip_spell_get_suggestions (const gchar *word)
 {
+	gossip_debug (DEBUG_DOMAIN, "Support disabled, could not get suggestions");
+
 	return NULL;
 }
 
 gboolean
 gossip_spell_check (const gchar *word)
 {
+	gossip_debug (DEBUG_DOMAIN, "Support disabled, could not check spelling");
+
 	return TRUE;
 }
 
 const char *
 gossip_spell_get_language_name (const char *lang)
 {
+	gossip_debug (DEBUG_DOMAIN, "Support disabled, could not get language name");
+
 	return NULL;
 }
 
 GList *
 gossip_spell_get_language_codes (void)
 {
+	gossip_debug (DEBUG_DOMAIN, "Support disabled, could not get language codes");
+
 	return NULL;
 }
 
