@@ -35,6 +35,7 @@
 typedef struct {
 	gchar    *name;
 	guint     name_notify_id;
+	guint     room_notify_id;
 
 	gboolean  show_avatars;
 	guint     show_avatars_notify_id;
@@ -46,6 +47,9 @@ static void        theme_manager_finalize                 (GObject            *o
 static void        theme_manager_notify_name_cb           (GossipConf         *conf,
 							   const gchar        *key,
 							   gpointer            user_data);
+static void        theme_manager_notify_room_cb           (GossipConf         *conf,
+							   const gchar        *key,
+							   gpointer            user_data);
 static void        theme_manager_notify_show_avatars_cb   (GossipConf         *conf,
 							   const gchar        *key,
 							   gpointer            user_data);
@@ -118,6 +122,12 @@ gossip_theme_manager_init (GossipThemeManager *manager)
 					theme_manager_notify_name_cb,
 					manager);
 
+	priv->room_notify_id =
+		gossip_conf_notify_add (gossip_conf_get (),
+					GOSSIP_PREFS_CHAT_THEME_CHAT_ROOM,
+					theme_manager_notify_room_cb,
+					manager);
+
 	gossip_conf_get_string (gossip_conf_get (),
 				GOSSIP_PREFS_CHAT_THEME,
 				&priv->name);
@@ -142,6 +152,7 @@ theme_manager_finalize (GObject *object)
 	priv = GET_PRIV (object);
 
 	gossip_conf_notify_remove (gossip_conf_get (), priv->name_notify_id);
+	gossip_conf_notify_remove (gossip_conf_get (), priv->room_notify_id);
 	gossip_conf_notify_remove (gossip_conf_get (), priv->show_avatars_notify_id);
 		
 	g_free (priv->name);
@@ -175,6 +186,14 @@ theme_manager_notify_name_cb (GossipConf  *conf,
 	g_signal_emit (manager, signals[THEME_CHANGED], 0, NULL);
 }
 
+static void
+theme_manager_notify_room_cb (GossipConf  *conf,
+			      const gchar *key,
+			      gpointer     user_data)
+{
+	g_signal_emit (user_data, signals[THEME_CHANGED], 0, NULL);
+}
+
 static void
 theme_manager_notify_show_avatars_cb (GossipConf  *conf,
 				      const gchar *key,
