@@ -19,22 +19,23 @@
  */
 
 #include <config.h>
-
 #include <string.h>
 #include <unistd.h>
-
 #include <gtk/gtk.h> 
 #include <glade/glade.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-href.h>
+
+#ifdef HAVE_GNOME
 #include <libgnomeui/libgnomeui.h>  
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <loudmouth/loudmouth.h>
+#endif
 
-#include <libgossip/gossip-session.h>
+#include <libgossip/gossip-debug.h>
+#include <libgossip/gossip-conf.h>
 #include <libgossip/gossip-protocol.h>
-#include <libgossip/gossip-vcard.h>
+#include <libgossip/gossip-session.h>
 #include <libgossip/gossip-utils.h>
+#include <libgossip/gossip-vcard.h>
 
 #include "gossip-account-chooser.h"
 #include "gossip-app.h"
@@ -42,8 +43,7 @@
 #include "gossip-image-chooser.h"
 #include "gossip-preferences.h"
 
-#define DEBUG_MSG(x)
-/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");  */
+#define DEBUG_DOMAIN "VCardDialog"
 
 #define STRING_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
@@ -90,7 +90,9 @@ typedef struct {
 
 	gint       last_account_selected;
 
+#ifdef HAVE_GNOME
 	GnomeThumbnailFactory *thumbs;
+#endif
 } GossipVCardDialog;
 
 static void     vcard_dialog_avatar_chooser_response_cb (GtkWidget         *widget,
@@ -157,10 +159,9 @@ vcard_dialog_avatar_chooser_response_cb (GtkWidget         *widget,
 
 		path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (widget));
 		if (path) {
-			gconf_client_set_string (gossip_app_get_gconf_client (),
-						 GCONF_PATH "/ui/avatar_directory",
-						 path,
-						 NULL);
+			gossip_conf_set_string (gossip_conf_get (),
+						 GOSSIP_PREFS_UI_AVATAR_DIRECTORY,
+						 path);
 			g_free (path);
 		}
 	} else if (response == GTK_RESPONSE_NO) {
@@ -198,10 +199,11 @@ vcard_dialog_avatar_clicked_cb (GtkWidget         *button,
 
  	gtk_dialog_set_default_response (GTK_DIALOG (chooser_dialog), GTK_RESPONSE_ACCEPT);
 
-	path = gconf_client_get_string (gossip_app_get_gconf_client (),
-					GCONF_PATH "/ui/avatar_directory",
-					NULL);
-
+	path = NULL;
+	gossip_conf_get_string (gossip_conf_get (),
+				 GOSSIP_PREFS_UI_AVATAR_DIRECTORY,
+				 &path);
+	
  	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser_dialog),
 					     path ? path : g_get_home_dir ());
 	g_free (path);
@@ -224,6 +226,7 @@ vcard_dialog_avatar_clicked_cb (GtkWidget         *button,
 	gtk_widget_show (chooser_dialog);
 }
 
+#ifdef HAVE_GNOME
 static GdkPixbuf *
 vcard_dialog_scale_down_to_width (GdkPixbuf *pixbuf, gint wanted_width)
 {
@@ -246,11 +249,13 @@ vcard_dialog_scale_down_to_width (GdkPixbuf *pixbuf, gint wanted_width)
 
 	return g_object_ref (pixbuf);
 }
+#endif
 
 static void 
 vcard_dialog_avatar_update_preview_cb (GtkFileChooser    *chooser,
 				       GossipVCardDialog *dialog) 
 {
+#ifdef HAVE_GNOME
 	gchar *uri;
 
 	uri = gtk_file_chooser_get_preview_uri (chooser);
@@ -262,9 +267,10 @@ vcard_dialog_avatar_update_preview_cb (GtkFileChooser    *chooser,
 		gchar     *mime_type;
 
 		if (!dialog->thumbs) {
-			dialog->thumbs = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
+			dialog->thumbs =
+				gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
 		}
-		
+
 		mime_type = gnome_vfs_get_mime_type (uri);
 		pixbuf = gnome_thumbnail_factory_generate_thumbnail (dialog->thumbs,
 								     uri,
@@ -287,6 +293,7 @@ vcard_dialog_avatar_update_preview_cb (GtkFileChooser    *chooser,
 	}
 
 	gtk_file_chooser_set_preview_widget_active (chooser, TRUE);
+#endif
 }
 
 static void
@@ -366,12 +373,12 @@ vcard_dialog_get_vcard_cb (GossipResult       result,
 	const guchar  *avatar;
 	gsize          avatar_size;
 
-	DEBUG_MSG (("VCardDialog: Got a VCard response"));
+	gossip_debug (DEBUG_DOMAIN, "Got a VCard response");
 
 	vcard_dialog_lookup_stop (dialog);
 
 	if (result != GOSSIP_RESULT_OK) {
-		DEBUG_MSG (("VCardDialog: VCard result was not good"));
+		gossip_debug (DEBUG_DOMAIN, "VCard result was not good");
 		return;
 	}
 
@@ -417,7 +424,7 @@ vcard_dialog_set_vcard (GossipVCardDialog *dialog)
 	gsize                 avatar_size;
 
 	if (!gossip_app_is_connected ()) {
-		DEBUG_MSG (("VCardDialog: Not connected, not setting VCard"));
+		gossip_debug (DEBUG_DOMAIN, "Not connected, not setting VCard");
 		return;
 	}
 
@@ -468,7 +475,7 @@ static void
 vcard_dialog_set_vcard_cb (GossipResult       result, 
 			   GossipVCardDialog *dialog)
 {
-	DEBUG_MSG (("VCardDialog: Got a VCard response"));
+	gossip_debug (DEBUG_DOMAIN, "Got a VCard response");
 	
 	gtk_widget_destroy (dialog->dialog);
 }
@@ -554,7 +561,7 @@ gossip_vcard_dialog_show (GtkWindow *parent)
 
 	dialog = g_new0 (GossipVCardDialog, 1);
 
-	glade = gossip_glade_get_file (GLADEDIR "/main.glade",
+	glade = gossip_glade_get_file ("main.glade",
 				       "vcard_dialog",
 				       NULL,
 				       "vcard_dialog", &dialog->dialog,
